@@ -141,6 +141,11 @@ create_table_pages_rtf <- function(rs, cntnt, lpg_rows) {
   # print(fdat)
   # str(fdat)
   
+  # Add stub_var into control_cols for adding indentation
+  if ("..stub_var" %in% names(fdat)) {
+    control_cols <- c(control_cols, "..stub_var")
+  }
+  
   # Reset keys, since prep_data can add/remove columns for stub
   keys <- names(fdat)
   # print("Keys")
@@ -159,17 +164,17 @@ create_table_pages_rtf <- function(rs, cntnt, lpg_rows) {
   widths_uom <- get_col_widths_variable(fdat, ts, labels, 
                                         rs$font, rs$font_size, rs$units, 
                                         rs$gutter_width) 
+  
   # print("Widths UOM")
   # print(widths_uom)
   
   # Split long text strings into multiple rows. Number of rows are stored in
   # ..row variable. If too slow, may need to be rewritten in C
   fdat <- split_cells_variable(fdat, widths_uom, rs$font, 
-                                rs$font_size, rs$units, rs$output_type, rs$char_width)$data 
+                                rs$font_size, rs$units, rs$output_type, rs$char_width, ts)$data 
   # print("split_cells")
   # print(fdat)
   
-  
   # Break columns into pages
   wraps <- get_page_wraps(rs$line_size, ts, 
                           widths_uom, 0, control_cols)  # No gutter width for RTF
@@ -273,7 +278,7 @@ create_table_rtf <- function(rs, ts, pi, content_blank_row, wrap_flag,
   # rs, ts, widths,  algns, halgns, talgn
   rws <- get_table_body_rtf(rs, pi$data, pi$col_width, 
                             pi$col_align, pi$table_align, ts$borders, 
-                            ts$first_row_blank, ts$continuous, styles, pgind)
+                            ts$first_row_blank, ts$continuous, styles, pgind, ts)
   
   # Default to content width
   ls <- rs$content_size[["width"]]
@@ -729,6 +734,11 @@ get_spanning_header_rtf <- function(rs, ts, pi) {
   
   conv <- rs$twip_conversion
   talgn <- pi$table_align
+  
+  # Detect continuous underline and insert gap, adjust widths
+  if (length(wlvl) > 0) {
+    wlvl <- get_spanning_gap_rtf(wlvl, conv)
+  }
 
   # Table alignment
   ta <- "\\trql"
@@ -887,12 +897,136 @@ get_spanning_header_rtf <- function(rs, ts, pi) {
   return(res)
 }
 
+#' @description Check gap and insert blank for RTF
+#' @details Check gap and insert blank for RTF
+#' @noRd
+get_spanning_gap_rtf <- function(wlvl, conv, gap_twips = 100){
+  
+  ret <- list()
+  
+  for (k in 1:length(wlvl)) {
+    
+    df <- wlvl[[k]]
+    
+    # Extract spanning and underline only for detection
+    df_span <- df[df$span > 0 & df$underline == TRUE,] 
+    
+    if (nrow(df_span) < 2) {
+      ret[[k]] <- df
+    } else {
+      gap_width <- gap_twips/conv
+      
+      df_span$order <- as.numeric(stri_extract_first_regex(df_span$name, "\\d+"))
+      
+      # Empty template for gap data
+      df_gap <- na.omit(
+        data.frame(
+          span = NA_integer_,
+          width = NA,
+          label = NA_character_,
+          align = NA_character_,
+          n = NA_integer_,
+          name = NA_character_,
+          underline = NA,
+          col_span = NA_integer_,
+          bold = NA,
+          order = NA_integer_
+        )
+      )
+      
+      for (i in 1:nrow(df_span)) {
+        
+        # Temporary gap data for stacking
+        df_gap_temp <- data.frame(
+          span = -1,
+          width = NA,
+          label = "",
+          align = "",
+          n = NA_integer_,
+          name = NA_character_,
+          underline = TRUE,
+          col_span = 1,
+          bold = FALSE,
+          order = NA_integer_
+        )
+        
+        cur_order <- df_span$order[i]
+        
+        # Process by first, last, and others
+        if (i == 1){
+          next_order <- df_span$order[i + 1]
+          
+          # Continuous underline detection
+          if (next_order - cur_order== 1) {
+            
+            # Create the gap data after this spanning cell
+            df_gap_temp$width <- gap_width
+            df_gap_temp$order <- cur_order + 0.5
+            df_gap_temp$name <- paste0("Span", df_gap_temp$order)
+            df_gap <- rbind(df_gap, df_gap_temp)
+            
+            # Reduce the gap width for spanning cell
+            df_span$width[i] <- df_span$width[i] - (gap_width/2)
+          }
+        } else if (i == nrow(df_span)){
+          pre_order <- df_span$order[i - 1]
+          
+          # Continuous underline detection
+          if (cur_order - pre_order == 1) {
+            
+            # Reduce the gap width for spanning cell
+            df_span$width[i] <- df_span$width[i] - (gap_width/2)
+          }
+          
+        } else {
+          pre_order <- df_span$order[i - 1]
+          next_order <- df_span$order[i + 1]
+          
+          # Continuous underline detection
+          if (next_order - cur_order == 1 |
+              cur_order - pre_order == 1) {
+            
+            # Create the gap data after this spanning cell
+            if (next_order - cur_order == 1) {
+              df_gap_temp$width <- gap_width
+              df_gap_temp$order <- cur_order + 0.5
+              df_gap_temp$name <- paste0("Span", df_gap_temp$order)
+              df_gap <- rbind(df_gap, df_gap_temp)
+              
+              # Reduce the gap width for spanning cell
+              df_span$width[i] <- df_span$width[i] - (gap_width/2)
+            }
+            
+            if (cur_order - pre_order == 1) {
+              # Reduce the gap width for spanning cell
+              df_span$width[i] <- df_span$width[i] - (gap_width/2)
+            }
+          }
+        }
+      } # End of data row loop
+      
+      # Drop order
+      df_span <- df_span[, setdiff(names(df_span), "order")]
+      df_gap <- df_gap[, setdiff(names(df_gap), "order")]
+      
+      # Stack together and sort
+      df_ret <- rbind(df_span, df_gap, df[!(df$span > 0 & df$underline == TRUE),])
+      df_ret <- df_ret[order(df_ret$name),]
+      
+      ret[[k]] <- df_ret
+      
+    } # End of gap process
+  }
+  
+  return(ret)
+}
+
 #' @description This function counts lines per row independently because
 #' the ..row field does not account for page wrapping.  Need number
 #' of lines on this particular page.
 #' @noRd
 get_table_body_rtf <- function(rs, tbl, widths, algns, talgn, tbrdrs, 
-                               frb, continuous = FALSE, styles, pgind) {
+                               frb, continuous = FALSE, styles, pgind, ts) {
   
   if ("..blank" %in% names(tbl))
     flgs <- tbl$..blank
@@ -980,7 +1114,7 @@ get_table_body_rtf <- function(rs, tbl, widths, algns, talgn, tbrdrs,
     
     
 
-    if (flgs[i] %in% c("B", "L")) {
+    if (flgs[i] %in% c("B", "A", "L")) {
       
       # Deal with blank and label rows
       radj <- 0
@@ -1007,9 +1141,13 @@ get_table_body_rtf <- function(rs, tbl, widths, algns, talgn, tbrdrs,
     }
     
     mxrw <- 1
+    
+    # Prepare indenting convert
+    conv_twips <- rs$twip_conversion
   
+    defs <- ts$col_defs
 
-    if (flgs[i] %in% c("B", "L")) {
+    if (flgs[i] %in% c("B", "A", "L")) {
       
       # Deal with label rows
       vl <- t[i, 1]
@@ -1042,11 +1180,29 @@ get_table_body_rtf <- function(rs, tbl, widths, algns, talgn, tbrdrs,
       
       stl <- get_cell_styles(nms[1], styles, flgs, i, tbl)
       
+      # Get indenting information
+      rtf_ind <- ""
+      if (!is.null(defs[[nms[1]]]$indent)) {
+        
+        ind <- floor(defs[[nms[1]]]$indent*conv_twips)
+        rtf_ind <- paste0("\\li", ind, " ")
+        
+      } else if (nms[1] == "stub" & !is.null(ts$stub)) {
+        
+        stub_var <- tbl$..stub_var[i]
+        if (!is.null(defs[[stub_var]]$indent)) {
+          ind <- floor(defs[[stub_var]]$indent*conv_twips)
+          rtf_ind <- paste0("\\li", ind, " ")
+        }
+      }
+      
+      vl <- paste0(rtf_ind, vl)
+      
       if ("bold" %in% stl) {
         vl <- paste0("\\b ", vl, "\\b0")
       }
       
-      ret[i] <- paste0(ret[i], ca[1], " ", vl, "\\cell")
+      ret[i] <- paste0(ret[i], ca[1], " ", vl, "\\cell\\li", rs$cell_padding)
       
       
       cl <- strsplit(vl, "\\line", fixed = TRUE)[[1]]
@@ -1091,12 +1247,29 @@ get_table_body_rtf <- function(rs, tbl, widths, algns, talgn, tbrdrs,
           
           stl <- get_cell_styles(nms[j], styles, flgs, i, tbl)
           
+          # Get indenting information
+          rtf_ind <- ""
+          if (!is.null(defs[[nms[j]]]$indent)) {
+            
+            ind <- floor(defs[[nms[j]]]$indent*conv_twips)
+            rtf_ind <- paste0("\\li", ind, " ")
+            
+          } else if (nms[j] == "stub" & !is.null(ts$stub)) {
+            
+            stub_var <- tbl$..stub_var[i]
+            if (!is.null(defs[[stub_var]]$indent)) {
+              ind <- floor(defs[[stub_var]]$indent*conv_twips)
+              rtf_ind <- paste0("\\li", ind, " ")
+            }
+          }
+          tb <- paste0(rtf_ind, tb)
+          
           if ("bold" %in% stl) {
             tb <- paste0("\\b ", tb, "\\b0") 
           }
           
           # Construct rtf
-          ret[i] <- paste0(ret[i], ca[j], " ", tb, "\\cell")
+          ret[i] <- paste0(ret[i], ca[j], " ", tb, "\\cell\\li", rs$cell_padding)
           
           vl <- t[i, j]
           if (all(class(vl) != "character"))
@@ -1140,8 +1313,6 @@ get_table_body_rtf <- function(rs, tbl, widths, algns, talgn, tbrdrs,
   
 }
 
-
-
 # Utility Functions -------------------------------------------------------
 
 titles_aligned <- function(ttls = NULL, ttlhdrs = NULL) {
