@@ -1,6 +1,6 @@
 context("HTML Tests")
 
-base_path <- "c:/packages/reporter/tests/testthat"
+base_path <- paste0(getwd(),"/tests/testthat")
 data_dir <- base_path
 
 base_path <- tempdir()
@@ -1232,7 +1232,7 @@ test_that("html36: Italic footnotes work as expected.", {
   
   dat <- mtcars[1:15, ]
   
-  tbl <- create_table(dat, borders = c( "none")) %>%
+  tbl <- create_table(dat, borders = c( "outside")) %>%
     spanning_header(cyl, disp, "Span 1", label_align = "left") %>%
     spanning_header(hp, wt, "Span 2", underline = FALSE, bold = FALSE) %>%
     spanning_header(qsec, vs, "Span 3", n = 10) %>%
@@ -1537,6 +1537,142 @@ test_that("html-44: Multi page table removes blank spaces.", {
     expect_equal(TRUE, TRUE)
 })
 
+test_that("html-45: Spanning header gap works as expected.", {
+  
+  if (dev == TRUE) {
+    fp <- file.path(base_path, "html/test45.html")
+    
+    dat <- mtcars[1:15, ]
+    
+    tbl <- create_table(dat, borders = c("outside")) %>%
+      spanning_header(cyl, disp, "Span 1", label_align = "left") %>%
+      spanning_header(hp, wt, "Span 2", underline = TRUE) %>%
+      spanning_header(qsec, vs, "Span 3", n = 10) %>%
+      spanning_header(cyl, hp, "Super Span", n = 11, level = 2) |> 
+      spanning_header(drat, gear, "Super Duper\nWrapped Span", n = 11, level = 2)
+    
+    rpt <- create_report(fp, output_type = "HTML", font = fnt,
+                         font_size = fsz, orientation = "landscape") %>%
+      set_margins(top = 1, bottom = 1) %>%
+      page_header("Left", c("Right1", "Right2", "Right3"), blank_row = "below") %>%
+      titles("Table 1.0", "My Nice Table") %>%
+      add_content(tbl) %>%
+      footnotes("My footnote 1", "My footnote 2") %>%
+      page_footer("Left1", "Center1", "Right1")
+    
+    res <- write_report(rpt)
+    res
+    res$column_widths
+    
+    expect_equal(file.exists(fp), TRUE)
+    expect_equal(res$pages, 1)
+    
+  } else {
+    expect_true(TRUE)
+  }
+  
+})
+
+test_that("html-46: Table with blank_before works as expected.", {
+  
+  if (dev == TRUE) {
+    fp <- file.path(base_path, "html/test46.html")
+    
+    
+    # Setup
+    subjid <- 100:109
+    name <- c("Quintana, Gabriel", "Allison, Blas", "Minniear, Presley",
+              "al-Kazemi, Najwa", "Schaffer, Ashley", "Laner, Tahma", 
+              "Perry, Sean", "Crews, Deshawn Joseph", "Person, Ladon", 
+              "Smith, Shaileigh")
+    sex <- c("M", "F", "F", "M", "M", "F", "M", "F", "F", "M")
+    age <- c(41, 53, 43, 39, 47, 52, 21, 38, 62, 26)
+    arm <- c(rep("A", 5), rep("B", 5))
+    
+    # Create data frame
+    df <- data.frame(subjid, name, sex, age, arm)
+    
+    
+    tbl1 <- create_table(df, first_row_blank = FALSE) %>%
+      define(subjid, label = "Subject ID", align = "left", width = 1) %>% 
+      define(name, label = "Subject Name", width = 1) %>% 
+      define(sex, label = "Sex") %>% 
+      define(age, label = "Age") %>% 
+      define(arm, label = "Arm", 
+             blank_before = TRUE, 
+             dedupe = TRUE, 
+             align = "right") #%>% 
+    # spanning_header(sex, arm, label = "Here is a spanning header")
+    
+    
+    rpt <- create_report(fp, output_type = "HTML", font = fnt, font_size = fsz) %>%
+      page_header(left = "Experis", right = c("Study ABC", "Status: Closed")) %>%
+      # options_fixed(line_count = 46) %>% 
+      titles("Table 1.0", "Analysis Data Subject Listing\n And more stuff", 
+             "Safety Population", align = "center", bold = TRUE) %>%
+      footnotes("Program Name: table1_0.R", 
+                "Here is a big long footnote that is going to wrap\n at least once") %>%
+      page_footer(left = "Time", center = "Confidential", 
+                  right = "Page [pg] of [tpg]") %>%
+      add_content(tbl1) 
+    
+    
+    res <- write_report(rpt)
+    res
+    expect_equal(file.exists(fp), TRUE)
+  } else {
+    expect_true(TRUE)
+  }
+})
+
+test_that("html-47: Three level stub and indentation work as expected.", {
+  
+  if (dev == TRUE) {
+    fp <- file.path(base_path, "html/test47.html")
+    
+    
+    # Setup
+    cat <- c(rep("Kaplan-Meier estimates", 6), 
+             rep("Cox PH estimates and some more really long stuff", 6))
+    grp <- c("25th percentile", "25th percentile", 
+             "median (weeks)", "median (weeks)",
+             "75th percentile", "75th percentile",
+             "25th percentile", "25th percentile", 
+             "median (weeks)", "median (weeks)",
+             "75th percentile", "75th percentile")
+    ci <- c(NA, "95% confidence interval",
+            NA, "95% confidence interval",
+            NA, "95% confidence interval",
+            NA, "95% confidence interval",
+            NA, "95% confidence interval",
+            NA, "95% confidence interval")
+    values <- c(41, 53, 43, 39, 47, 52, 38, 25, 37, 23, 78, 21)
+    
+    # Create data frame
+    df <- data.frame(cat, grp, ci, values, stringsAsFactors = FALSE)
+    
+    tbl1 <- create_table(df) %>%
+      stub(c(cat, grp, ci), "Estimates", width = 1.5) %>% 
+      define(cat, label_row = TRUE, blank_after = TRUE, indent = 0.15) %>%
+      define(grp, indent = .25) %>%
+      define(ci, indent = .5) %>%
+      define(values, label = "Values")
+    
+    rpt <- create_report(fp, output_type = "HTML", font = fnt,
+                         font_size = fsz) %>%
+      titles("Table 3.0", "Analysis of Time to Initial PSGA Success in Weeks") %>% 
+      page_header("Sponsor", "Study") %>% 
+      add_content(tbl1) %>% 
+      page_footer("Time", "Confidential", "Page")
+    
+    
+    res <- write_report(rpt)
+    
+    expect_equal(file.exists(fp), TRUE)
+  } else {
+    expect_true(TRUE)
+  }
+})
 
 # User Tests --------------------------------------------------------------
 
