@@ -92,6 +92,37 @@ test_that("utils5: split_cells works as expected.", {
   
 })
 
+test_that("utils5-2: split_cells with indentation works as expected.", {
+  
+  
+  a1 <- c("one", "two", "three")
+  b1 <- c("here is a\n long value", "Some sort of value", 
+          "Another value that goes on and on")
+  c1 <- c("here is a longer value", "Really", "Medium value")
+  ..blank <- ""
+  ..page <- NA
+  ..row <- NA
+  
+  df <- data.frame(a1, b1, c1, ..blank, ..page, ..row, stringsAsFactors = FALSE)
+  
+  w <- c(a1 = .5, b1 = 1.5, c1 = 1.25)
+  
+  conversion_factor <- .083333 
+  
+  wc <- floor(w / conversion_factor)
+  
+  tbl <- create_table(df) %>%
+    define("b1", indent = 0.25)
+  
+  res1 <- split_cells(df, wc, ts = tbl, char_width = 0.11)
+  res1
+  
+  expect_equal(nrow(res1), 7) 
+  expect_equal(res1$b1, c("  here is a", "   long value", "  Some sort of", 
+                          "  value", "  Another value", "  that goes on and", "  on"))
+  
+})
+
 test_that("utils6: align_cells works as expected.", {
   
   
@@ -148,7 +179,7 @@ test_that("utils9: create_stub works as expected.", {
   d <- create_stub(x, tbl)
   
   expect_equal(d$stub, c("a", "b", "c", "a", "b", "c"))
-  
+  expect_equal(d$..stub_var, c("a1", "b1", "c1", "a1", "b1", "c1"))
 })
 
 
@@ -275,7 +306,7 @@ test_that("utils15: split_cells_variable works as expected.", {
   cw <- get_col_widths_variable(df, tbl, lbls, "Arial", 12, "inches", .2)
   cw
   
-  res <- split_cells_variable(df, cw, "Arial", 12, "inches", "RTF")
+  res <- split_cells_variable(df, cw, "Arial", 12, "inches", "RTF", ts = tbl)
   res$widths
   
   expect_equal(any(class(res$data) == "data.frame"), TRUE)
@@ -284,6 +315,36 @@ test_that("utils15: split_cells_variable works as expected.", {
   
 })
 
+test_that("utils15: split_cells_variable works with indentation as expected.", {
+  
+  # split_cells_variable <- function(x, col_widths, font, font_size, units)
+  
+  df <- data.frame(car = c("Dart", "Bart", "Here is another car name"),
+                   cyl = c(8, 3, 4),
+                   disp = c("My lovely disp and it gets longer", 
+                            "Here is a big long string value to exceed 2 inches",
+                            "Short"), stringsAsFactors = FALSE)
+  
+  tbl <- create_table(df) %>% 
+    define(car, label = "Cars", width = 1, indent = 0.8) %>% 
+    define(cyl, width = 1.5, indent = 1) %>% 
+    define(disp, width = 2, indent = 1.5) 
+  
+  lbls <- get_labels(df, tbl)
+  
+  cw <- get_col_widths_variable(df, tbl, lbls, "Arial", 12, "inches", .2)
+  cw
+  
+  res <- split_cells_variable(df, cw, "Arial", 12, "inches", "RTF", ts = tbl)
+  res$widths
+  
+  expect_equal(any(class(res$data) == "data.frame"), TRUE)
+  expect_equal(res$data[1, "..row"], 5)
+  expect_equal(res$data[2, "..row"], 7)
+  expect_equal(res$data[3, "..row"], 4) 
+  
+})
+
 
 test_that("utils16: get_width function works as expected.", {
   
@@ -480,8 +541,10 @@ test_that("utils22: split_cells_variable() works as expected.", {
                     col3 = c("my big string I want to wrap", "fork", "bork"),
                     ..row = c(NA, NA, NA), stringsAsFactors = FALSE)
   
+  ts <- create_table(dat)
+  
   res <- split_cells_variable(dat, c(col1 = 1, col2 = 1, col3 = 1), 
-                              "Arial", 12, "inches", "RTF")
+                              "Arial", 12, "inches", "RTF", ts = ts)
   res
   
   expect_equal(nrow(res$data), 3)
@@ -656,3 +719,63 @@ test_that("utils30: has_glue() works as expected.", {
   expect_equal(res3, TRUE)
   
 })
+
+test_that("utils31: strwdth() works as expected.", {
+  
+  strngs <- c("hello", "goodbye", paste0("here is something", supsc('6')))
+  
+  
+  
+  # pdf(NULL)
+  # par(family = 'mono', ps = 10)
+  # 
+  # res <- strwidth(strngs, un = "inches")
+  # 
+  # dev.off()
+  
+  res <- c(0.4166667, 0.5833333, 1.5000000)
+  
+  
+  
+  pdf(NULL)
+  par(family = 'mono', ps = 10)
+  
+  res1 <- strwdth(strngs, un = "inches")
+  
+  dev.off()
+  
+  res1
+  
+  expect_equal(res[1] == round(res1[1], 7), TRUE) 
+  expect_equal(res[2] == round(res1[2], 7), TRUE) 
+   
+  
+  # pdf(NULL)
+  # par(family = 'sans', ps = 10)
+  # 
+  # res3 <- strwidth(strngs, un = "inches")
+  # 
+  # dev.off()
+  
+  res3 <- c(0.2933333, 0.5272222, 1.1733333)
+  
+  pdf(NULL)
+  par(family = 'sans', ps = 10)
+  
+  res4 <- strwdth(strngs, un = "inches")
+  
+  dev.off()
+  
+  res4
+  
+  # print(res1)
+  # print(res2)
+  
+  expect_equal(all(res != res4), TRUE) 
+  expect_equal(res3[1] == round(res4[1], 7), TRUE) 
+  expect_equal(res3[2] == round(res4[2], 7), TRUE) 
+  
+})
+
+
+
